import { TutorialStep, CodeBlock } from '@/components/default/tutorial';

const create = `create table notes (
  id bigserial primary key,
  title text
);

insert into notes(title)
values
  ('Today I created a Supabase project.'),
  ('I added some data and queried it from Next.js.'),
  ('It was awesome!');
`.trim();

const server = `import { createClient } from '@/utils/supabase/server'

export default async function Page() {
  const supabase = await createClient()
  const { data: notes } = await supabase.from('notes').select()

  return <pre>{JSON.stringify(notes, null, 2)}</pre>
}
`.trim();

const client = `'use client'

import { createClient } from '@/utils/supabase/client'
import { useEffect, useState } from 'react'

export default function Page() {
  const [notes, setNotes] = useState<any[] | null>(null)
  const supabase = createClient()

  useEffect(() => {
    const getData = async () => {
      const { data } = await supabase.from('notes').select()
      setNotes(data)
    }
    getData()
  }, [])

  return <pre>{JSON.stringify(notes, null, 2)}</pre>
}
`.trim();

export const FetchDataSteps = () => {
  return (
    <ol className='flex flex-col gap-6'>
      <TutorialStep title='Create some tables and insert some data'>
        <p>
          Head over to the{' '}
          <a
            href='https://supabase.com/dashboard/project/_/editor'
            className='font-bold hover:underline text-foreground/80'
            target='_blank'
            rel='noreferrer'
          >
            Table Editor
          </a>{' '}
          for your Supabase project to create a table and insert some example
          data. If you&apos;re stuck for creativity, you can copy and paste the
          following into the{' '}
          <a
            href='https://supabase.com/dashboard/project/_/sql/new'
            className='font-bold hover:underline text-foreground/80'
            target='_blank'
            rel='noreferrer'
          >
            SQL Editor
          </a>{' '}
          and click RUN!
        </p>
        <CodeBlock code={create} />
      </TutorialStep>

      <TutorialStep title='Query Supabase data from Next.js'>
        <p>
          To create a Supabase client and query data from an Async Server
          Component, create a new page.tsx file at{' '}
          <span className='relative rounded bg-muted px-[0.3rem] py-[0.2rem] font-mono text-xs font-medium text-secondary-foreground border'>
            /app/notes/page.tsx
          </span>{' '}
          and add the following.
        </p>
        <CodeBlock code={server} />
        <p>Alternatively, you can use a Client Component.</p>
        <CodeBlock code={client} />
      </TutorialStep>

      <TutorialStep title='Build in a weekend and scale to millions!'>
        <p>You&apos;re ready to launch your product to the world! 🚀</p>
      </TutorialStep>
    </ol>
  );
};
